import { BaseManager } from '../base.manager';
import { Injectable } from '@nestjs/common';

export abstract class BaseCreateManager<Entity> extends BaseManager {
  protected result: Entity;
  protected duplicateColumn: string[];
  abstract get entityTarget(): any;

  setData(entity: Entity): void {
    this.data = entity;
  }

  async prepareData(): Promise<void> {
    Object.assign(this.data, {
      creator_id: this.user.id,
      creator_name: this.user.name,
      created_at: new Date().getTime(),
      updated_at: new Date().getTime(),
    });
  }

  async process(): Promise<void> {
    this.result = await this.dataService.create(
      this.queryRunner,
      this.entityTarget,
      this.data,
    );
  }

  async getResult(): Promise<Entity> {
    return await this.dataService.getOneByOptions({
      where: {
        id: this.result['id'],
      },
    });
  }
}
