import { Module } from "@nestjs/common";
import { UserPrivilegeModel } from "./data/model/user-privilege.model";
import { ConfigModule } from "@nestjs/config";
import { TypeOrmModule } from "@nestjs/typeorm";
import { CONNECTION_NAME } from "src/core/strings/constants/base.constants";
import { UserPrivilegeDataService } from "./data/service/user-privilege-data.service";
import { UserPrivilegeReadService } from "./data/service/user-privilege-read.service";
import { UserPrivilegeReadController } from "./infrastructure/user-privilege-read.controller";
import { UserPrivilegeReadOrchestrator } from "./domain/usecases/user-privilege-read.orchestrator";
import { UserPrivilegeDataController } from "./infrastructure/user-privilege-data.controller";
import { UserPrivilegeDataOrchestrator } from "./domain/usecases/user-privilege-data.orchestrator";
import { CreateUserPrivilegeManager } from "./domain/usecases/managers/create-user-privilege.manager";
import { CqrsModule } from "@nestjs/cqrs";
import { IndexUserPrivilegeManager } from "./domain/usecases/managers/index-user-privilege.manager";
import { DeleteUserPrivilegeManager } from "./domain/usecases/managers/delete-user-privilege.manager";
import { UpdateUserPrivilegeManager } from "./domain/usecases/managers/update-user-privilege.manager";
import { ActiveUserPrivilegeManager } from "./domain/usecases/managers/active-user-privilege.manager";
import { ConfirmUserPrivilegeManager } from "./domain/usecases/managers/confirm-user-privilege.manager";
import { InactiveUserPrivilegeManager } from "./domain/usecases/managers/inactive-user-privilege.manager";
import { DetailUserPrivilegeManager } from "./domain/usecases/managers/detail-user-privilege.manager";

@Module({
    imports: [
      ConfigModule.forRoot(),
      TypeOrmModule.forFeature([UserPrivilegeModel], CONNECTION_NAME.DEFAULT),
      CqrsModule,
    ],
    controllers: [
      UserPrivilegeDataController,
      UserPrivilegeReadController
    ],
    providers: [
      IndexUserPrivilegeManager,
      DetailUserPrivilegeManager,
      CreateUserPrivilegeManager,
      DeleteUserPrivilegeManager,
      UpdateUserPrivilegeManager,
      ActiveUserPrivilegeManager,
      ConfirmUserPrivilegeManager,
      InactiveUserPrivilegeManager,

      UserPrivilegeDataService,
      UserPrivilegeReadService,

      UserPrivilegeDataOrchestrator,
      UserPrivilegeReadOrchestrator,
    ],
  })
  export class UserPrivilegeModule {}